@@ -158,12 +158,17 @@ bool MtpServer::hasStorage(MtpStorageID id) {
     return (getStorage(id) != NULL);
 }
 
+void MtpServer::stop() {
+    mRunning = false;
+}
+
 void MtpServer::run() {
     int fd = mFD;
 
     VLOG(1) << "MtpServer::run fd: " << fd;
 
-    while (1) {
+    mRunning = true;
+    while (mRunning) {
         int ret = mRequest.read(fd);
         if (ret < 0) {
             PLOG(ERROR) << "request read returned " << ret;
